@@ -89,7 +89,7 @@ impl GameCollisionShape {
             0 => (self.box_.length + self.box_.width + self.box_.height) / 6.,
             1 => self.sphere.diameter / 2.,
             2 => self.cylinder.diameter / 2.,
-            _ => panic!("Invalid shape type: {}", self.shape_type),
+            _ => panic!("Invalid shape type: #{}", self.shape_type),
         }
     }
 }
@@ -222,6 +222,13 @@ pub struct BasicShotInfo {
     is_forwards: bool,
 }
 
+impl Default for BasicShotInfo {
+    #[inline]
+    fn default() -> Self {
+        Self::not_found()
+    }
+}
+
 impl BasicShotInfo {
     #[inline]
     pub const fn not_found() -> Self {
